Module: Dry::View::Tilt::Haml Private

Defined in:
lib/dry/view/tilt/haml.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

API:

  • private

Class Method Summary collapse

Class Method Details

.activateObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



17
18
19
20
# File 'lib/dry/view/tilt/haml.rb', line 17

def self.activate
  # Requiring hamlit will register the engine with Tilt
  self
end

.requirementsObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



7
8
9
10
11
12
13
14
15
# File 'lib/dry/view/tilt/haml.rb', line 7

def self.requirements
  ["hamlit", "    dry-view requires hamlit (3.0 or greater) for full compatibility when rendering .haml templates (e.g. implicitly capturing block content when yielding)\n\n    To ignore this and use another engine for .haml templates, dereigster this adapter before calling your views:\n\n    Dry::View::Tilt.deregister_adatper(:haml)\n  ERROR\nend\n"]